@@ -25,9 +25,10 @@
     + graceful handling of exit (close all handles even when stopped with <CTRL>-C
     + one file per day, appending
     + autostart
-    - file management, data compression
+    - file management, data compression, (/var/spool/... /etc/flowmon.conf
     - init.d (flowmon start/stop)
     - fix appending to *.log.gdf file after restart
+    - javascript interface
 
    Requirements:
         g++
@@ -37,7 +38,6 @@
 */
 
 
-
 #include "../biosig.h"
 
 #include <errno.h>
@@ -92,16 +92,14 @@ void stop() {
         if (fid2) fclose(fid2);
 }
 
-uint8_t idata[300];
-uint8_t odata[300];
 const void *outPtr = odata+3; 
 
 /*
-        crc16_a001: computers crc of a modbus packet and writes it at the end;
+        crc16_a001: computes crc of a modbus packet and writes it at the end;
         (remark: its not CCITT's crc16 but uses 0xA001 polynomial) 
         input :
-                data  : packet with is crc
-                n     : lenght of data without the crc
+                data  : packet with its crc
+                n     : length of data without the crc
 
         ouput : crc16 value 
 */
@@ -133,7 +131,7 @@ uint16_t crc16_a001(uint8_t data[], size_t n)
 int read_register(uint8_t slave, uint8_t cmd, uint16_t reg) { 
  
         idata[0] = slave;		// address
-        idata[1] = 3; //cmd;	// read - 
+        idata[1] = 3; 			//cmd;	// read -
         *(uint16_t*)(idata+2) = bswap_16((uint16_t)reg);  // register 
         *(uint16_t*)(idata+4) = bswap_16(0x0004);  // length
         crc16_a001(idata,6); // compute crc and add at and
@@ -179,7 +177,7 @@ uint32_t oldDay=0, newDay;
 gdf_time gdfTime;
 char flag_GZIP = 0;
 
-char logfile[] = "flowmonYYYYMMDD.log.gdf";
+char logfile[48] = "flowmonYYYYMMDD.log.gdf";
 char debugfile[] = "flowmonDD.log.txt";
 
 
@@ -197,16 +195,16 @@ char debugfile[] = "flowmonDD.log.txt";
 		"   devicename: default value is /dev/ttyS0\n"
 		"   outfile:    logs the recorded data\n"
                 "               If no outfile is provided, the data will be logged into daily files named flowmon<$date>.log.gdf \n"
-                "   debugfile:  logs the data in ascii text"
+                "   debugfile:  logs the data in ascii text\n"
                 "               If no outfile is provided, the data will be logged into daily files named flowmon<$day-of-month>.log.txt \n"
                 "   -V#		verbose level #=0 is no messages, #=9 is highest level(debugging) messages\n"
-                "   -h, --help:	display this help text"
-                "   -z		save outfile in gzipped format"  
+                "   -h, --help:        display this help text\n"
+                "   -z		save outfile in gzipped format\n"
                 " \n\n"
 	;
 	if (argc<2) {
 		fprintf(stdout,"%s",help);
-//		exit(0);
+		return(0);
 	}
 
 	/* Sanity checks of input arguments */
@@ -260,8 +258,7 @@ char debugfile[] = "flowmonDD.log.txt";
         newDay = gdfTime>>32;
         gdf_time2tm_time_r(gdfTime, &T);
 
-
-	if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 010\n");
+	if (VERBOSE_LEVEL>7) fprintf(stdout,"%s (line %d): err %d\n",__FILE__,__LINE__,errno);
 
         //open the device(com port) to be non-blocking (read will return immediately)
         fd = open(devicename, O_RDWR | O_NOCTTY | O_NONBLOCK);
@@ -271,8 +268,7 @@ char debugfile[] = "flowmonDD.log.txt";
         }
         tcgetattr(fd,&oldtio); // save current port settings
 
-
-	if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
+        if (VERBOSE_LEVEL>7) fprintf(stdout,"%s (line %d): fd=%d\n",__FILE__,__LINE__,fd);
 
         // set new port settings for canonical input processing
         // newtio.c_cflag = BAUD | CRTSCTS | DATABITS | STOPBITS | PARITYON | PARITY | CLOCAL | CREAD;
@@ -285,8 +281,12 @@ char debugfile[] = "flowmonDD.log.txt";
         tcflush(fd, TCIOFLUSH);
         tcsetattr(fd,TCSANOW,&newtio);
 
-if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
-
+        if (VERBOSE_LEVEL>7) fprintf(stdout,"%s (line %d): err %d\n",__FILE__,__LINE__,errno);
+        if (errno) {
+                fprintf(stderr,"%s (line %d)  %d %s\n", __FILE__, __LINE__, errno, strerror(errno));
+                stop();
+                return(errno);
+        }
 
 #if 1
 	if (debugFile)
@@ -296,27 +296,22 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
                 fid2 = fopen(debugfile,"a");
         }
 
-
-	if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 031\n");
-
         {
-	if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 032\n");
 		hdr = constructHDR(4 ,0);
-	if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 035\n");
 		hdr->SampleRate = 1;
 		hdr->SPR     =  1;
 		hdr->NRec    = -1;
 		hdr->EVENT.N =  0;
 		hdr->FILE.COMPRESSION = 0;
-	if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 042\n");
-                {
+
+		{
                         // channel 1: time stamp
 			CHANNEL_TYPE *hc = hdr->CHANNEL + 0;
 			hc->LeadIdCode = 0;
 			strcpy(hc->Label,"time ");
 			hc->GDFTYP  = 8;	// uint64
 			hc->SPR     = hdr->SPR;
-	if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 044\n");
+
 			hc->PhysMax = ldexp(1,32);
 			hc->PhysMin = 0;
 			hc->DigMax  = ldexp(1,64);
@@ -325,9 +320,7 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
                         hdr->AS.bpb += GDFTYP_BITS[hc->GDFTYP]>>3;
 		}
 
-	if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 046\n");
-
-                {
+		{
                         // channel 2: volume
 			CHANNEL_TYPE *hc = hdr->CHANNEL + 1;
 			hc->LeadIdCode = 0;
@@ -339,7 +332,7 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
 			hc->PhysMin = -hc->PhysMax;
 			hc->DigMax  = hc->PhysMax;
 			hc->DigMin  = hc->PhysMin;
-                        hdr->AS.bpb += GDFTYP_BITS[hc->GDFTYP]>>3;
+			hdr->AS.bpb += GDFTYP_BITS[hc->GDFTYP]>>3;
 
                         read_register(247, 3, 0x6384) ; // f32: Skalierung Totalisator, and s8: Einheit des Totalisatorwertes mit 4 Byte offset. 
                         //read_register(247, 3, 0x6386) ; // s8: Einheit des Totalisatorwertes
@@ -347,9 +340,9 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
                                 hc->PhysDimCode = PhysDimCode("l");
                         else 
                                 hc->PhysDimCode = 0; // "unknown"
-                        
 		}
-                {
+
+		{
                         // channel 3: flow
 			CHANNEL_TYPE *hc = hdr->CHANNEL + 2;
 			hc->LeadIdCode = 0;
@@ -383,7 +376,8 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
                         //read_register(247, 3, 0x6121) ; // u16: Heizleistung
                         //read_register(247, 3, 0x6122) ; // u16: Dynamik
 		}
-                {
+
+		{
                         // channel 4: temparature
 			CHANNEL_TYPE *hc = hdr->CHANNEL + 3;
 			hc->LeadIdCode = 0;
@@ -397,6 +391,7 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
                         hc->PhysDimCode = 6048; // degree Celsius
                         hdr->AS.bpb += GDFTYP_BITS[hc->GDFTYP]>>3;
 		}
+
                 if (hdr->NS > 4) {
                         // channel 5: type of gas
 			CHANNEL_TYPE *hc = hdr->CHANNEL + 4;
@@ -419,8 +414,6 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
 
 		hdr->AS.rawdata = (uint8_t*)realloc(hdr->AS.rawdata,hdr->AS.bpb);
 
-	if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 017\n");
-
 		hdr->ID.Manufacturer.Name  = "Voegtlin";
 /*
 		hdr->ID.Manufacturer.Model = "Flow Meter";
@@ -452,18 +445,10 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
                 hdr->ID.Manufacturer.SerialNumber = hdr->ID.Manufacturer.Version+strlen(hdr->ID.Manufacturer.Version)+1;
                 sprintf((char*)(hdr->ID.Manufacturer.SerialNumber),"%d",beu32p(outPtr)); 
         
-
-	if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 018\n");
-
-		        
 		hdr->FLAG.UCAL = 1;
 		hdr->TYPE      = GDF;
 		hdr->VERSION   = 2.0;
 		if (outFile) hdr->FileName  = strdup(outFile);
-
-
-	if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 019\n");
-
         }
 #endif
 
@@ -476,7 +461,6 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
         read_register(247, 3, 0x000d) ; // u16: Hardwarefehler
         //read_register(247, 3, 0x000e) ; // u16: Regelmode
         //read_register(247, 3, 0x000f) ; // u16: Ramp
-                                 
          
         read_register(247, 3, 0x0013) ; // device address: default 247 (0xf7)
         //read_register(247, 3, 0x0020) ; 
@@ -490,7 +474,6 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
         //read_register(247, 3, 0x6382) ; // f32: Totalisator 2 - nicht rückstellbar
         read_register(247, 3, 0x6384) ; // f32: Skalierung Totalisator, and s8: Einheit des Totalisatorwertes mit 4 Byte offset. 
         //read_register(247, 3, 0x6386) ; // s8: Einheit des Totalisatorwertes
-        
 
         if (outFile) {
                 // open once write all data into single log file
@@ -498,16 +481,11 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
 		hdr = sopen(outFile, "a", hdr);
 		if (VERBOSE_LEVEL>7) hdr2ascii(hdr,stdout,4);
 
-                if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 010 %i\n", (int)hdr->NRec);
-
 		if (serror2(hdr)) {
 			destructHDR(hdr); 
 			return(EXIT_FAILURE);
 		}
 
-                if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
-
-//		if (VERBOSE_LEVEL>6) hdr2ascii(hdr, stdout, 3);
 		if (hdr->FILE.OPEN < 2) {
 			destructHDR(hdr);
 			hdr = NULL;
@@ -515,8 +493,6 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
 			exit(-1);
 		}
 
-                if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 030\n");
-
 		hdr->AS.rawdata = (uint8_t*)realloc(hdr->AS.rawdata,hdr->AS.bpb);
 		if (hdr->NRec < 0) hdr->NRec = 0;
 	}
@@ -528,6 +504,7 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
          ***************************************************************************/
 
         fid = fdopen(fd, "r+");
+
         while (1) {
                 /***
                         get data
@@ -555,37 +532,27 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
                 if ( (newDay != oldDay) && !outFile) {
                         // open/close daily log file  
 
-                if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 110\n");
-
                         sclose(hdr);
 			hdr->NRec = -1;
-                        sprintf(logfile,"flowmon%04i%02i%02i.log.gdf",T.tm_year+1900,T.tm_mon+1,T.tm_mday);
+                        sprintf(logfile,"flowmon%04d%02d%02d.log.gdf",T.tm_year+1900,T.tm_mon+1,T.tm_mday);
                         hdr->FILE.COMPRESSION = flag_GZIP;
                         hdr = sopen(logfile, "a", hdr);
 
-                if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 120 %p\n", hdr);
-
                         if (serror2(hdr)) {
 				destructHDR(hdr); 
 				return(EXIT_FAILURE);
                         }
 
-                if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 125 %i\n", (int)hdr->NRec);
-
                         if (!hdr->FILE.OPEN) {
 				destructHDR(hdr);
 				hdr = NULL;
         			fprintf(stderr,"Could not open output file  %s\n", logfile);
 			}
 
-                if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 130\n");
-
 			hdr->AS.rawdata = (uint8_t*)realloc(hdr->AS.rawdata,hdr->AS.bpb);
 			if (hdr->NRec<0) hdr->NRec = 0;
                 }
 
-                if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 140\n");
-
                 if ( (newDay != oldDay) && !debugFile) {
                         // open/close daily debug file
 			if (fid2>0) fclose(fid2);
@@ -593,15 +560,11 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
 			fid2 = fopen(debugfile,"a");
                 }
 
-                if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 150\n");
-
                 if (newDay != oldDay) {
                         oldDay = newDay;
                 };
 
 
-                if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 190\n");
-
                 /***
                         parse data
                 ***/
@@ -619,8 +582,6 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 020\n");
                         hdr->NRec += ifwrite(hdr->AS.rawdata, hdr->AS.bpb, 1, hdr);
                         ifflush(hdr);
 
-                if (VERBOSE_LEVEL>7) fprintf(stdout,"FLOWMON 290 %i\n", (int)hdr->NRec);
-
 			/*******************************************************************
 			 * Write HTML file 
 			 *******************************************************************/
